check_cont: Check containers exist

View source: R/check_cont.R

check_contR Documentation

Check containers exist

Description

Check that a list of containers are valid.

Usage

check_cont(cont, verbose = TRUE)

Arguments

cont

Which Docker container to use on each OS (NULL means no container will be used for that OS). See here for a list of all official Bioconductor Docker container versions.

verbose

Print messages.

Value

Null


rworkflows documentation built on May 6, 2026, 1:06 a.m.