Which Bioconductor version to use on each OS.
See bioc_r_versions documentation for all options.
r
Which R version to use on each OS.
python_version
Which python version to use on each OS
(e.g. "3.10", "3.7.5", or "3.x").
(NULL means python will not be installed on that OS).
See
here
or rworkflows:::gha_python_versions() for all available
python versions.
See
here for
details on the actions/setup-miniconda action.
See here for details on
the actions/setup-python action.
versions_explicit
Specify R/Bioc versions explicitly
(e.g. r: 4.2.0, bioc: 3.16)
as opposed to flexibly (e.g. r: "latest", bioc: "release").
run_check_cont
Check whether the requested container repo
(and the tag, if specified) exist using check_cont.
cont
Which Docker container to use on each OS
(NULL means no container will be used for that OS).
See
here
for a list of all official Bioconductor Docker container versions.
rspm
Which R repository manager to use on each OS
(NULL means the default will be used for that OS).