View source: R/get_description_repo.R
| get_description_repo | R Documentation |
Get the DESCRIPTION file information in data.table format for all R packages in standard R repositories (CRAN, Bioc). Can return a subset of results for specific packages as well.
get_description_repo(
refs = NULL,
db = NULL,
repo = c("BioCsoft", "BioCann", "BioCexp", "BioCworkflows", "CRAN"),
version = BiocManager::version(),
verbose = TRUE
)
refs |
Reference for one or more GitHub repository in owner/repo format
(e.g. |
db |
A data.table of R package metadata generated by biocPkgList. |
repo |
|
version |
|
verbose |
Print messages. |
Named list of desc objects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.