Learn R Programming

rworkflows (version 1.0.10)

get_description_repo: Get DESCRIPTION files for R repos

Description

Get the DESCRIPTION file information in data.table format for all R packages in standard R repositories (CRAN, Bioc). Can return a subset of results for specific packages as well.

Usage

get_description_repo(
  refs = NULL,
  db = NULL,
  repo = c("BioCsoft", "BioCann", "BioCexp", "BioCworkflows", "CRAN"),
  version = BiocManager::version(),
  verbose = TRUE
)

Value

Named list of desc objects.

Arguments

refs

Reference for one or more GitHub repository in owner/repo format (e.g."neurogenomics/rworkflows"), or an R package name (e.g. "rworkflows").

db

A data.table of R package metadata generated by biocPkgList.

repo

character(1) The requested Bioconductor repository. The default is to pull from the "BioCsoft" repository. Possible repositories include "BioCsoft", "BioCexp", "BioCworkflows", "BioCann", and "CRAN". Note that not all repos are available for all versions, particularly older versions.

version

character(1) or package_version indicating the Bioconductor version (e.g., "3.22"). Defaults to the "current version" provided by BiocManager::version(). The keywords "release" and "devel" are also accepted.

verbose

Print messages.