Get the DESCRIPTION file information in data.table format for all R packages in standard R repositories (CRAN, Bioc). Can return a subset of results for specific packages as well.
get_description_repo(
refs = NULL,
db = NULL,
repo = c("BioCsoft", "BioCann", "BioCexp", "BioCworkflows", "CRAN"),
version = BiocManager::version(),
verbose = TRUE
)Named list of desc objects.
Reference for one or more GitHub repository in owner/repo format
(e.g."neurogenomics/rworkflows"), or an R package name
(e.g. "rworkflows").
A data.table of R package metadata generated by biocPkgList.
character(1) The requested Bioconductor repository. The default
is to pull from the "BioCsoft" repository. Possible repositories include
"BioCsoft", "BioCexp", "BioCworkflows", "BioCann", and "CRAN". Note that
not all repos are available for all versions, particularly older versions.
character(1) or package_version indicating the
Bioconductor version (e.g., "3.22"). Defaults to the "current version"
provided by BiocManager::version(). The keywords "release" and "devel"
are also accepted.
Print messages.